==> forge-2%3a1.0.3-1-x86_64.pkg.tar.xz: usr/share/Forge/doc/html/menudata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.htm"},
{text:"Modules",url:"modules.htm"},
{text:"Namespaces",url:"namespaces.htm",children:[
{text:"Namespace List",url:"namespaces.htm"},
{text:"Namespace Members",url:"namespacemembers.htm",children:[
{text:"All",url:"namespacemembers.htm"},
{text:"Functions",url:"namespacemembers_func.htm"},
{text:"Typedefs",url:"namespacemembers_type.htm"},
{text:"Enumerations",url:"namespacemembers_enum.htm"},
{text:"Enumerator",url:"namespacemembers_eval.htm"}]}]},
{text:"Data Structures",url:"annotated.htm",children:[
{text:"Data Structures",url:"annotated.htm"},
{text:"Data Structure Index",url:"classes.htm"},
{text:"Class Hierarchy",url:"hierarchy.htm"},
{text:"Data Fields",url:"functions.htm",children:[
{text:"All",url:"functions.htm",children:[
{text:"a",url:"functions.htm#index_a"},
{text:"c",url:"functions.htm#index_c"},
{text:"d",url:"functions.htm#index_d"},
{text:"e",url:"functions.htm#index_e"},
{text:"f",url:"functions.htm#index_f"},
{text:"g",url:"functions.htm#index_g"},
{text:"h",url:"functions.htm#index_h"},
{text:"i",url:"functions.htm#index_i"},
{text:"k",url:"functions.htm#index_k"},
{text:"l",url:"functions.htm#index_l"},
{text:"m",url:"functions.htm#index_m"},
{text:"o",url:"functions.htm#index_o"},
{text:"p",url:"functions.htm#index_p"},
{text:"r",url:"functions.htm#index_r"},
{text:"s",url:"functions.htm#index_s"},
{text:"v",url:"functions.htm#index_v"},
{text:"w",url:"functions.htm#index_w"},
{text:"~",url:"functions.htm#index_0x7e"}]},
{text:"Functions",url:"functions_func.htm",children:[
{text:"a",url:"functions_func.htm#index_a"},
{text:"c",url:"functions_func.htm#index_c"},
{text:"d",url:"functions_func.htm#index_d"},
{text:"e",url:"functions_func.htm#index_e"},
{text:"f",url:"functions_func.htm#index_f"},
{text:"g",url:"functions_func.htm#index_g"},
{text:"h",url:"functions_func.htm#index_h"},
{text:"i",url:"functions_func.htm#index_i"},
{text:"k",url:"functions_func.htm#index_k"},
{text:"l",url:"functions_func.htm#index_l"},
{text:"m",url:"functions_func.htm#index_m"},
{text:"p",url:"functions_func.htm#index_p"},
{text:"r",url:"functions_func.htm#index_r"},
{text:"s",url:"functions_func.htm#index_s"},
{text:"v",url:"functions_func.htm#index_v"},
{text:"w",url:"functions_func.htm#index_w"},
{text:"~",url:"functions_func.htm#index_0x7e"}]},
{text:"Variables",url:"functions_vars.htm"},
{text:"Related Functions",url:"functions_rela.htm"}]}]},
{text:"Files",url:"files.htm",children:[
{text:"File List",url:"files.htm"},
{text:"Globals",url:"globals.htm",children:[
{text:"All",url:"globals.htm",children:[
{text:"b",url:"globals.htm#index_b"},
{text:"c",url:"globals.htm#index_c"},
{text:"f",url:"globals.htm#index_f"}]},
{text:"Functions",url:"globals_func.htm",children:[
{text:"f",url:"globals_func.htm#index_f"}]},
{text:"Typedefs",url:"globals_type.htm"},
{text:"Enumerations",url:"globals_enum.htm"},
{text:"Enumerator",url:"globals_eval.htm",children:[
{text:"f",url:"globals_eval.htm#index_f"}]},
{text:"Macros",url:"globals_defs.htm"}]}]},
{text:"Examples",url:"examples.htm"}]}

==> forge-2%3a1.0.4-1-x86_64.pkg.tar.xz: usr/share/Forge/doc/html/menudata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.htm"},
{text:"Modules",url:"modules.htm"},
{text:"Namespaces",url:"namespaces.htm",children:[
{text:"Namespace List",url:"namespaces.htm"},
{text:"Namespace Members",url:"namespacemembers.htm",children:[
{text:"All",url:"namespacemembers.htm"},
{text:"Functions",url:"namespacemembers_func.htm"},
{text:"Typedefs",url:"namespacemembers_type.htm"},
{text:"Enumerations",url:"namespacemembers_enum.htm"},
{text:"Enumerator",url:"namespacemembers_eval.htm"}]}]},
{text:"Data Structures",url:"annotated.htm",children:[
{text:"Data Structures",url:"annotated.htm"},
{text:"Data Structure Index",url:"classes.htm"},
{text:"Class Hierarchy",url:"hierarchy.htm"},
{text:"Data Fields",url:"functions.htm",children:[
{text:"All",url:"functions.htm",children:[
{text:"a",url:"functions.htm#index_a"},
{text:"c",url:"functions.htm#index_c"},
{text:"d",url:"functions.htm#index_d"},
{text:"e",url:"functions.htm#index_e"},
{text:"f",url:"functions.htm#index_f"},
{text:"g",url:"functions.htm#index_g"},
{text:"h",url:"functions.htm#index_h"},
{text:"i",url:"functions.htm#index_i"},
{text:"k",url:"functions.htm#index_k"},
{text:"l",url:"functions.htm#index_l"},
{text:"m",url:"functions.htm#index_m"},
{text:"o",url:"functions.htm#index_o"},
{text:"p",url:"functions.htm#index_p"},
{text:"r",url:"functions.htm#index_r"},
{text:"s",url:"functions.htm#index_s"},
{text:"v",url:"functions.htm#index_v"},
{text:"w",url:"functions.htm#index_w"},
{text:"~",url:"functions.htm#index__7E"}]},
{text:"Functions",url:"functions_func.htm",children:[
{text:"a",url:"functions_func.htm#index_a"},
{text:"c",url:"functions_func.htm#index_c"},
{text:"d",url:"functions_func.htm#index_d"},
{text:"e",url:"functions_func.htm#index_e"},
{text:"f",url:"functions_func.htm#index_f"},
{text:"g",url:"functions_func.htm#index_g"},
{text:"h",url:"functions_func.htm#index_h"},
{text:"i",url:"functions_func.htm#index_i"},
{text:"k",url:"functions_func.htm#index_k"},
{text:"l",url:"functions_func.htm#index_l"},
{text:"m",url:"functions_func.htm#index_m"},
{text:"p",url:"functions_func.htm#index_p"},
{text:"r",url:"functions_func.htm#index_r"},
{text:"s",url:"functions_func.htm#index_s"},
{text:"v",url:"functions_func.htm#index_v"},
{text:"w",url:"functions_func.htm#index_w"},
{text:"~",url:"functions_func.htm#index__7E"}]},
{text:"Variables",url:"functions_vars.htm"},
{text:"Related Functions",url:"functions_rela.htm"}]}]},
{text:"Files",url:"files.htm",children:[
{text:"File List",url:"files.htm"},
{text:"Globals",url:"globals.htm",children:[
{text:"All",url:"globals.htm",children:[
{text:"b",url:"globals.htm#index_b"},
{text:"c",url:"globals.htm#index_c"},
{text:"f",url:"globals.htm#index_f"}]},
{text:"Functions",url:"globals_func.htm",children:[
{text:"f",url:"globals_func.htm#index_f"}]},
{text:"Typedefs",url:"globals_type.htm"},
{text:"Enumerations",url:"globals_enum.htm"},
{text:"Enumerator",url:"globals_eval.htm",children:[
{text:"f",url:"globals_eval.htm#index_f"}]},
{text:"Macros",url:"globals_defs.htm"}]}]},
{text:"Examples",url:"examples.htm"}]}
